==> os-postfix-1.8.txz: usr/local/opnsense/mvc/app/controllers/OPNsense/Postfix/Api/SenderbccController.php <==
<?php

/*
 * Copyright (C) 2018 Michael Muenz <m.muenz@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

namespace OPNsense\Postfix\Api;

use \OPNsense\Base\ApiMutableModelControllerBase;

class SenderbccController extends ApiMutableModelControllerBase
{
    protected static $internalModelName = 'senderbcc';
    protected static $internalModelClass = '\OPNsense\Postfix\Senderbcc';

    public function searchSenderbccAction()
    {
        return $this->searchBase('senderbccs.senderbcc', array("enabled", "from", "to"));
    }

    public function getSenderbccAction($uuid = null)
    {
        return $this->getBase('senderbcc', 'senderbccs.senderbcc', $uuid);
    }

    public function addSenderbccAction()
    {
        return $this->addBase('senderbcc', 'senderbccs.senderbcc');
    }

    public function delSenderbccAction($uuid)
    {
        return $this->delBase('senderbccs.senderbcc', $uuid);
    }

    public function setSenderbccAction($uuid)
    {
        return $this->setBase('senderbcc', 'senderbccs.senderbcc', $uuid);
    }

    public function toggleSenderbccAction($uuid)
    {
        return $this->toggleBase('senderbccs.senderbcc', $uuid);
    }
}

==> os-postfix-1.21.txz: usr/local/opnsense/mvc/app/controllers/OPNsense/Postfix/Api/SenderbccController.php <==
<?php

/*
 * Copyright (C) 2018 Michael Muenz <m.muenz@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

namespace OPNsense\Postfix\Api;

use OPNsense\Base\ApiMutableModelControllerBase;

class SenderbccController extends ApiMutableModelControllerBase
{
    protected static $internalModelName = 'senderbcc';
    protected static $internalModelClass = '\OPNsense\Postfix\Senderbcc';

    public function searchSenderbccAction()
    {
        return $this->searchBase('senderbccs.senderbcc', array("enabled", "from", "to"));
    }

    public function getSenderbccAction($uuid = null)
    {
        return $this->getBase('senderbcc', 'senderbccs.senderbcc', $uuid);
    }

    public function addSenderbccAction()
    {
        return $this->addBase('senderbcc', 'senderbccs.senderbcc');
    }

    public function delSenderbccAction($uuid)
    {
        return $this->delBase('senderbccs.senderbcc', $uuid);
    }

    public function setSenderbccAction($uuid)
    {
        return $this->setBase('senderbcc', 'senderbccs.senderbcc', $uuid);
    }

    public function toggleSenderbccAction($uuid)
    {
        return $this->toggleBase('senderbccs.senderbcc', $uuid);
    }
}
